# caption_images

### Description
This component captions inputted images using [BLIP](https://huggingface.co/docs/transformers/model_doc/blip).

### **Inputs/Outputs**

See [`fondant_component.yaml`](fondant_component.yaml) for a more detailed description on all the input/output parameters. 

